pub(crate) fn truncate_le(bytes: &[u8], bits_precision: u32) -> &[u8] ⓘExpand description
Interpret bytes as a little endian integer and extract bits_precision number of least
significant bits, returning a truncated input if it exceeds the requested precision.